@@ -40,10 +40,6 @@ impl Decode for StartDecoderChain {
         track_panic!(ErrorKind::Other)
     }
 
-    fn is_idle(&self) -> bool {
-        true
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         ByteCount::Unknown
     }
@@ -69,10 +65,6 @@ where
         self.0.b.decode(buf, eos).map(|(n, i)| (n, i.map(|i| (i,))))
     }
 
-    fn is_idle(&self) -> bool {
-        self.0.b.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         self.0.b.requiring_bytes()
     }
@@ -90,10 +82,6 @@ where
             .map(|(n, x)| (n, x.map(|(t, i)| (t.0, i))))
     }
 
-    fn is_idle(&self) -> bool {
-        self.0.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         self.0.requiring_bytes()
     }
@@ -111,10 +99,6 @@ where
             .map(|(n, x)| (n, x.map(|(t, i)| (t.0, t.1, i))))
     }
 
-    fn is_idle(&self) -> bool {
-        self.0.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         self.0.requiring_bytes()
     }
@@ -132,10 +116,6 @@ where
             .map(|(n, x)| (n, x.map(|(t, i)| (t.0, t.1, t.2, i))))
     }
 
-    fn is_idle(&self) -> bool {
-        self.0.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         self.0.requiring_bytes()
     }
@@ -153,10 +133,6 @@ where
             .map(|(n, x)| (n, x.map(|(t, i)| (t.0, t.1, t.2, t.3, i))))
     }
 
-    fn is_idle(&self) -> bool {
-        self.0.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         self.0.requiring_bytes()
     }
@@ -174,10 +150,6 @@ where
             .map(|(n, x)| (n, x.map(|(t, i)| (t.0, t.1, t.2, t.3, t.4, i))))
     }
 
-    fn is_idle(&self) -> bool {
-        self.0.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         self.0.requiring_bytes()
     }
@@ -195,10 +167,6 @@ where
             .map(|(n, x)| (n, x.map(|(t, i)| (t.0, t.1, t.2, t.3, t.4, t.5, i))))
     }
 
-    fn is_idle(&self) -> bool {
-        self.0.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         self.0.requiring_bytes()
     }
@@ -217,10 +185,6 @@ where
             .map(|(n, x)| (n, x.map(|(t, i)| (t.0, t.1, t.2, t.3, t.4, t.5, t.6, i))))
     }
 
-    fn is_idle(&self) -> bool {
-        self.0.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         self.0.requiring_bytes()
     }
@@ -520,10 +484,6 @@ where
         Ok((offset + size, item))
     }
 
-    fn is_idle(&self) -> bool {
-        self.a.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         self.a
             .requiring_bytes()
@@ -645,10 +605,6 @@ impl<D: Decode> Decode for Buffered<D> {
         }
     }
 
-    fn is_idle(&self) -> bool {
-        self.item.is_none() && self.inner.is_idle()
-    }
-
     fn requiring_bytes(&self) -> ByteCount {
         if self.item.is_some() {
             ByteCount::Finite(0)
